==> jc-1.4.0.tar.gz: soot/dava/internal/AST/ASTIfElseNode.h <==
// public class soot.dava.internal.AST.ASTIfElseNode

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 2492f1f7a753b788 soot_AbstractUnit
// @dep_class a1cb59fbdd01f4af soot_dava_internal_AST_ASTControlFlowNode
// @dep_class ffbcf419647c4082 soot_dava_internal_AST_ASTIfElseNode
// @dep_class cab1e395a09c5dd8 soot_dava_internal_AST_ASTLabeledNode
// @dep_class 76430e9a28f2113d soot_dava_internal_AST_ASTNode
// @dep_class 6ddedfee878f127 soot_tagkit_AbstractHost

// header file dependencies
// @dep_header soot_dava_internal_AST_ASTControlFlowNode

#include "soot/dava/internal/AST/ASTControlFlowNode.h"

#ifndef _JC_soot_dava_internal_AST_ASTIfElseNode_H_
#define _JC_soot_dava_internal_AST_ASTIfElseNode_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_List$object;
struct _jc_soot_UnitPrinter$object;
struct _jc_soot_dava_internal_SET_SETNodeLabel$object;
struct _jc_soot_jimple_ConditionExpr$object;

// Typedefs
typedef struct _jc_soot_dava_internal_AST_ASTIfElseNode$sub_refs	_jc_soot_dava_internal_AST_ASTIfElseNode$sub_refs;
typedef struct _jc_soot_dava_internal_AST_ASTIfElseNode$sub_nonrefs	_jc_soot_dava_internal_AST_ASTIfElseNode$sub_nonrefs;
typedef struct _jc_soot_dava_internal_AST_ASTIfElseNode$refs	_jc_soot_dava_internal_AST_ASTIfElseNode$refs;
typedef struct _jc_soot_dava_internal_AST_ASTIfElseNode$nonrefs	_jc_soot_dava_internal_AST_ASTIfElseNode$nonrefs;
typedef struct _jc_soot_dava_internal_AST_ASTIfElseNode$object	_jc_soot_dava_internal_AST_ASTIfElseNode$object;

typedef const struct _jc_soot_dava_internal_AST_ASTIfElseNode$vmethods	_jc_soot_dava_internal_AST_ASTIfElseNode$vmethods;
typedef const struct _jc_soot_dava_internal_AST_ASTIfElseNode$vtable	_jc_soot_dava_internal_AST_ASTIfElseNode$vtable;
typedef const struct _jc_soot_dava_internal_AST_ASTIfElseNode$vtype	_jc_soot_dava_internal_AST_ASTIfElseNode$vtype;

// Constructors
extern void _jc_soot_dava_internal_AST_ASTIfElseNode$method$_init$e617524d5aef48b5(_jc_env *, struct _jc_soot_dava_internal_AST_ASTIfElseNode$object *, struct _jc_soot_dava_internal_SET_SETNodeLabel$object *, struct _jc_object *, struct _jc_object *, struct _jc_object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_dava_internal_AST_ASTIfElseNode$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_dava_internal_AST_ASTIfElseNode$object *);
extern struct _jc_java_lang_String$object *_jc_soot_dava_internal_AST_ASTIfElseNode$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_dava_internal_AST_ASTIfElseNode$object *);
extern void _jc_soot_dava_internal_AST_ASTIfElseNode$method$toString$49ce0d4a4e59c2a6(_jc_env *, struct _jc_soot_dava_internal_AST_ASTIfElseNode$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_dava_internal_AST_ASTIfElseNode$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_dava_internal_AST_ASTIfElseNode$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_soot_dava_internal_AST_ASTIfElseNode$method_info$toString$49ce0d4a4e59c2a6;

// Virtual methods structure
struct _jc_soot_dava_internal_AST_ASTIfElseNode$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_dava_internal_AST_ASTIfElseNode$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_dava_internal_AST_ASTIfElseNode$object *);
	void	(*toString$49ce0d4a4e59c2a6)(_jc_env *, struct _jc_soot_dava_internal_AST_ASTIfElseNode$object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_dava_internal_AST_ASTIfElseNode$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_AbstractHost$vmethods	soot_tagkit_AbstractHost;
	_jc_soot_AbstractUnit$vmethods	soot_AbstractUnit;
	_jc_soot_dava_internal_AST_ASTNode$vmethods	soot_dava_internal_AST_ASTNode;
	_jc_soot_dava_internal_AST_ASTLabeledNode$vmethods	soot_dava_internal_AST_ASTLabeledNode;
	_jc_soot_dava_internal_AST_ASTControlFlowNode$vmethods	soot_dava_internal_AST_ASTControlFlowNode;
	_jc_soot_dava_internal_AST_ASTIfElseNode$vmethods	soot_dava_internal_AST_ASTIfElseNode;
};

// Vtype
struct _jc_soot_dava_internal_AST_ASTIfElseNode$vtype {
	_jc_type			type;
	_jc_soot_dava_internal_AST_ASTIfElseNode$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_internal_AST_ASTIfElseNode$sub_refs {
	struct _jc_object	*ifBody;
	struct _jc_object	*elseBody;
};

// Reference instance fields (object)
struct _jc_soot_dava_internal_AST_ASTIfElseNode$refs {
    _jc_soot_dava_internal_AST_ASTIfElseNode$sub_refs	soot_dava_internal_AST_ASTIfElseNode;
    _jc_soot_dava_internal_AST_ASTControlFlowNode$sub_refs	soot_dava_internal_AST_ASTControlFlowNode;
    _jc_soot_dava_internal_AST_ASTLabeledNode$sub_refs	soot_dava_internal_AST_ASTLabeledNode;
    _jc_soot_dava_internal_AST_ASTNode$sub_refs	soot_dava_internal_AST_ASTNode;
    _jc_soot_AbstractUnit$sub_refs	soot_AbstractUnit;
    _jc_soot_tagkit_AbstractHost$sub_refs	soot_tagkit_AbstractHost;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_internal_AST_ASTIfElseNode$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_dava_internal_AST_ASTIfElseNode$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_AbstractHost$sub_nonrefs	soot_tagkit_AbstractHost;
    _jc_soot_AbstractUnit$sub_nonrefs	soot_AbstractUnit;
    _jc_soot_dava_internal_AST_ASTNode$sub_nonrefs	soot_dava_internal_AST_ASTNode;
    _jc_soot_dava_internal_AST_ASTLabeledNode$sub_nonrefs	soot_dava_internal_AST_ASTLabeledNode;
    _jc_soot_dava_internal_AST_ASTControlFlowNode$sub_nonrefs	soot_dava_internal_AST_ASTControlFlowNode;
    _jc_soot_dava_internal_AST_ASTIfElseNode$sub_nonrefs	soot_dava_internal_AST_ASTIfElseNode;
};

// Object instance structure
struct _jc_soot_dava_internal_AST_ASTIfElseNode$object {
	_jc_soot_dava_internal_AST_ASTIfElseNode$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_internal_AST_ASTIfElseNode$vtype	*vtype;
	_jc_soot_dava_internal_AST_ASTIfElseNode$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_internal_AST_ASTIfElseNode$vtype _jc_soot_dava_internal_AST_ASTIfElseNode$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_internal_AST_ASTIfElseNode, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_internal_AST_ASTIfElseNode$class_object;

#endif	/* _JC_soot_dava_internal_AST_ASTIfElseNode_H_ */

==> jc-1.4.6.tar.gz: soot/dava/internal/AST/ASTIfElseNode.h <==
// public class soot.dava.internal.AST.ASTIfElseNode

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 2492f1f7a753b788 soot_AbstractUnit
// @dep_class a1cb59fbdd01f4af soot_dava_internal_AST_ASTControlFlowNode
// @dep_class ffbcf419647c4082 soot_dava_internal_AST_ASTIfElseNode
// @dep_class cab1e395a09c5dd8 soot_dava_internal_AST_ASTLabeledNode
// @dep_class 76430e9a28f2113d soot_dava_internal_AST_ASTNode
// @dep_class 6ddedfee878f127 soot_tagkit_AbstractHost

// header file dependencies
// @dep_header soot_dava_internal_AST_ASTControlFlowNode

#include "soot/dava/internal/AST/ASTControlFlowNode.h"

#ifndef _JC_soot_dava_internal_AST_ASTIfElseNode_H_
#define _JC_soot_dava_internal_AST_ASTIfElseNode_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_List$object;
struct _jc_soot_UnitPrinter$object;
struct _jc_soot_dava_internal_SET_SETNodeLabel$object;
struct _jc_soot_jimple_ConditionExpr$object;

// Typedefs
typedef struct _jc_soot_dava_internal_AST_ASTIfElseNode$sub_refs	_jc_soot_dava_internal_AST_ASTIfElseNode$sub_refs;
typedef struct _jc_soot_dava_internal_AST_ASTIfElseNode$sub_nonrefs	_jc_soot_dava_internal_AST_ASTIfElseNode$sub_nonrefs;
typedef struct _jc_soot_dava_internal_AST_ASTIfElseNode$refs	_jc_soot_dava_internal_AST_ASTIfElseNode$refs;
typedef struct _jc_soot_dava_internal_AST_ASTIfElseNode$nonrefs	_jc_soot_dava_internal_AST_ASTIfElseNode$nonrefs;
typedef struct _jc_soot_dava_internal_AST_ASTIfElseNode$object	_jc_soot_dava_internal_AST_ASTIfElseNode$object;

typedef const struct _jc_soot_dava_internal_AST_ASTIfElseNode$vmethods	_jc_soot_dava_internal_AST_ASTIfElseNode$vmethods;
typedef const struct _jc_soot_dava_internal_AST_ASTIfElseNode$vtable	_jc_soot_dava_internal_AST_ASTIfElseNode$vtable;
typedef const struct _jc_soot_dava_internal_AST_ASTIfElseNode$vtype	_jc_soot_dava_internal_AST_ASTIfElseNode$vtype;

// Constructors
extern void _jc_soot_dava_internal_AST_ASTIfElseNode$method$_init$e617524d5aef48b5(_jc_env *, struct _jc_soot_dava_internal_AST_ASTIfElseNode$object *, struct _jc_soot_dava_internal_SET_SETNodeLabel$object *, struct _jc_object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_dava_internal_AST_ASTIfElseNode$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_dava_internal_AST_ASTIfElseNode$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_dava_internal_AST_ASTIfElseNode$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_dava_internal_AST_ASTIfElseNode$object *) _JC_JCNI_ATTR;
extern void _jc_soot_dava_internal_AST_ASTIfElseNode$method$toString$49ce0d4a4e59c2a6(_jc_env *, struct _jc_soot_dava_internal_AST_ASTIfElseNode$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_dava_internal_AST_ASTIfElseNode$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_dava_internal_AST_ASTIfElseNode$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_soot_dava_internal_AST_ASTIfElseNode$method_info$toString$49ce0d4a4e59c2a6;

// Virtual methods structure
struct _jc_soot_dava_internal_AST_ASTIfElseNode$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_dava_internal_AST_ASTIfElseNode$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_dava_internal_AST_ASTIfElseNode$object *) _JC_JCNI_ATTR;
	void	(*toString$49ce0d4a4e59c2a6)(_jc_env *, struct _jc_soot_dava_internal_AST_ASTIfElseNode$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_dava_internal_AST_ASTIfElseNode$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_AbstractHost$vmethods	soot_tagkit_AbstractHost;
	_jc_soot_AbstractUnit$vmethods	soot_AbstractUnit;
	_jc_soot_dava_internal_AST_ASTNode$vmethods	soot_dava_internal_AST_ASTNode;
	_jc_soot_dava_internal_AST_ASTLabeledNode$vmethods	soot_dava_internal_AST_ASTLabeledNode;
	_jc_soot_dava_internal_AST_ASTControlFlowNode$vmethods	soot_dava_internal_AST_ASTControlFlowNode;
	_jc_soot_dava_internal_AST_ASTIfElseNode$vmethods	soot_dava_internal_AST_ASTIfElseNode;
};

// Vtype
struct _jc_soot_dava_internal_AST_ASTIfElseNode$vtype {
	_jc_type			type;
	_jc_soot_dava_internal_AST_ASTIfElseNode$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_internal_AST_ASTIfElseNode$sub_refs {
	struct _jc_object	*ifBody;
	struct _jc_object	*elseBody;
};

// Reference instance fields (object)
struct _jc_soot_dava_internal_AST_ASTIfElseNode$refs {
    _jc_soot_dava_internal_AST_ASTIfElseNode$sub_refs	soot_dava_internal_AST_ASTIfElseNode;
    _jc_soot_dava_internal_AST_ASTControlFlowNode$sub_refs	soot_dava_internal_AST_ASTControlFlowNode;
    _jc_soot_dava_internal_AST_ASTLabeledNode$sub_refs	soot_dava_internal_AST_ASTLabeledNode;
    _jc_soot_dava_internal_AST_ASTNode$sub_refs	soot_dava_internal_AST_ASTNode;
    _jc_soot_AbstractUnit$sub_refs	soot_AbstractUnit;
    _jc_soot_tagkit_AbstractHost$sub_refs	soot_tagkit_AbstractHost;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_internal_AST_ASTIfElseNode$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_dava_internal_AST_ASTIfElseNode$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_AbstractHost$sub_nonrefs	soot_tagkit_AbstractHost;
    _jc_soot_AbstractUnit$sub_nonrefs	soot_AbstractUnit;
    _jc_soot_dava_internal_AST_ASTNode$sub_nonrefs	soot_dava_internal_AST_ASTNode;
    _jc_soot_dava_internal_AST_ASTLabeledNode$sub_nonrefs	soot_dava_internal_AST_ASTLabeledNode;
    _jc_soot_dava_internal_AST_ASTControlFlowNode$sub_nonrefs	soot_dava_internal_AST_ASTControlFlowNode;
    _jc_soot_dava_internal_AST_ASTIfElseNode$sub_nonrefs	soot_dava_internal_AST_ASTIfElseNode;
};

// Object instance structure
struct _jc_soot_dava_internal_AST_ASTIfElseNode$object {
	_jc_soot_dava_internal_AST_ASTIfElseNode$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_internal_AST_ASTIfElseNode$vtype	*vtype;
	_jc_soot_dava_internal_AST_ASTIfElseNode$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_internal_AST_ASTIfElseNode$vtype _jc_soot_dava_internal_AST_ASTIfElseNode$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_internal_AST_ASTIfElseNode, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_internal_AST_ASTIfElseNode$class_object;

#endif	/* _JC_soot_dava_internal_AST_ASTIfElseNode_H_ */
